<?php
/**
 * Wild Book Customizer support
 *
 * @package WordPress
 * @since Wild Book 1.0
 */
 
/**
 * Implement Customizer additions and adjustments.
 *
 * @since Wild Book 1.0
 *
 * @param WP_Customize_Manager $wp_customize Customizer object.
 */
function wdb_customize_register( $wp_customize ) {
  /*
   * Modify default Wordpress sections and controls
   */
  $wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
  $wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
  $wp_customize->get_control( 'blogdescription' )->label = esc_html__( 'Site Description', 'wildbook' );
  $wp_customize->get_control( 'blogdescription' )->description = esc_html__( 'Site description is displayed after the title in the browser tab', 'wildbook' );
  $wp_customize->get_section( 'title_tagline' )->priority = 0;
	$wp_customize->get_section( 'header_image' )->title = esc_html__( 'Logo', 'wildbook' );
  $wp_customize->get_section( 'background_image' )->title = esc_html__( 'Sidebar Background Image', 'wildbook' );
  $wp_customize->get_section( 'colors' )->panel = 'colors';
  $wp_customize->get_section( 'colors' )->priority = 15;
  $wp_customize->get_section( 'colors' )->title = esc_html__( 'Content Area', 'wildbook' );
  $wp_customize->get_control( 'blogname' )->priority = 0;
  $wp_customize->get_control( 'blogdescription' )->priority = 10;
  $wp_customize->get_control( 'background_color' )->section = 'sidebar_colors';
  $wp_customize->remove_control('display_header_text');
  $wp_customize->remove_control('header_textcolor');

  $wp_customize->add_setting( 'display_site_title',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize'
    )
  );
  
  $wp_customize->add_control( 'display_site_title', array(
    'type'     => 'checkbox',
    'priority' => 5,
    'label'    => esc_html__( 'Display site title', 'wildbook' ),
    'section'  => 'title_tagline',
  ) );

  $wp_customize->add_setting(
    'tagline',
    array(
      'default' => '',
      'sanitize_callback' => 'wdb_textarea_sanitize',
      'transport' => 'postMessage'
    )
  );
 
  $wp_customize->add_control(
      'tagline',
      array(
        'type'    => 'textarea',
        'label'   => esc_html__( 'Tagline', 'wildbook' ),
        'description' => esc_html__( 'Tagline is displayed under the title or logo. You may use these HTML tags and attributes: a[href,title], strong, b, em, i, img[src,alt,title], p, span, br', 'wildbook' ),
        'section' => 'title_tagline',
      )
  );

  /*
   * Sidebar Background Image
   */
  $wp_customize->add_setting( 'background_dark_mask_opacity',
    array(
      'default' => 0.5,
      'sanitize_callback' => 'wdb_opacity_sanitize',
      'transport' => 'postMessage'
    )
  );
  
  $wp_customize->add_control( 'background_dark_mask_opacity', array(
    'type'        => 'range',
    'section'     => 'background_image',
    'label'       => esc_html__( 'Blackout', 'wildbook' ),
    'priority' => 30,
    'input_attrs' => array(
        'min'   => 0,
        'max'   => 1,
        'step'  => 0.05
    ),
  ) );

  $wp_customize->add_setting( 'sidebar_background_image_for_mobile',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url'
    )
  );

  $wp_customize->add_control(
    new WP_Customize_Image_Control(
      $wp_customize,
      'sidebar_background_image_for_mobile',
      array(
        'priority' => 20,
        'label'      => esc_html__( 'Image for mobile devices (optional)', 'wildbook' ),
        'section'    => 'background_image',
        'settings'   => 'sidebar_background_image_for_mobile'
      )
    )
   );

  /*
   * Header Image
   */

  $wp_customize->add_setting( 'logo_size',
    array(
      'default' => 13,
      'sanitize_callback' => 'wdb_logo_size_sanitize',
      'transport' => 'postMessage'
    )
  );
  
  $wp_customize->add_control( 'logo_size', array(
    'type'        => 'range',
    'section'     => 'header_image',
    'label'       => esc_html__( 'Size', 'wildbook' ),
    'input_attrs' => array(
        'min'   => 1,
        'max'   => 30,
        'step'  => 0.2
    ),
  ) );

  $wp_customize->add_setting( 'logo_margin_bottom',
    array(
      'default' => 1.8,
      'sanitize_callback' => 'wdb_logo_margin_bottom_sanitize',
      'transport' => 'postMessage'
    )
  );
  
  $wp_customize->add_control( 'logo_margin_bottom', array(
    'type'        => 'range',
    'section'     => 'header_image',
    'label'       => esc_html__( 'Bottom margin', 'wildbook' ),
    'input_attrs' => array(
        'min'   => 0,
        'max'   => 6,
        'step'  => 0.1
    ),
  ) );
  
  $wp_customize->add_setting( 'header_image_rounded',
    array(
      'sanitize_callback' => 'wdb_checkbox_sanitize',
      'transport' => 'postMessage'
    )
  );
  
  $wp_customize->add_control( 'header_image_rounded', array(
    'type'     => 'checkbox',
    'priority' => 10,
    'section'  => 'header_image',
    'label'    => esc_html__( 'Rounded (recomended for square images)', 'wildbook' ),
  ) );

  $wp_customize->add_setting( 'logo_link_url',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );

  $wp_customize->add_control( 'logo_link_url', array(
    'type'     => 'url',
    'priority' => 15,
    'section'  => 'header_image',
    'label'    => esc_html__( 'Link URL', 'wildbook' ),
    'description' => esc_html__( 'By default, homepage URL', 'wildbook' )
  ) ); 

  /*
   * Colors
   */
  $wp_customize->add_panel( 'colors', array(
    'priority' => 10,
    'title'    => esc_html__( 'Colors', 'wildbook' ),
  ) ); 

  // Sidebar Colors
  $wp_customize->add_section( 'sidebar_colors',
    array(
      'title' => esc_html__( 'Sidebar', 'wildbook' ),
      'priority' => 0,
      'panel' => 'colors'
    )
  );
  
  $wp_customize->add_setting( 'side_text_color',
    array(
      'default' => '#cccccc',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'side_text_color',
          array(
              'label' => esc_html__( 'Text', 'wildbook' ),
              'section' => 'sidebar_colors',
              'settings' => 'side_text_color',
          )
      )
  ); 
   
  $wp_customize->add_setting( 'main_nav_link_color',
    array(
      'default' => '#ffffff',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'main_nav_link_color',
          array(
              'label' => esc_html__( 'Links', 'wildbook' ),
              'section' => 'sidebar_colors',
              'settings' => 'main_nav_link_color',
          )
      )
  ); 
  
  $wp_customize->add_setting( 'main_nav_link_hover_color',
    array(
      'default' => '#dbca9e',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'main_nav_link_hover_color',
          array(
              'label' => esc_html__( 'Links (hover)', 'wildbook' ),
              'section' => 'sidebar_colors',
              'settings' => 'main_nav_link_hover_color',
          )
      )
  );  

  $wp_customize->add_setting( 'side_icons_color',
    array(
      'default' => '#ffffff',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'side_icons_color',
          array(
              'label' => esc_html__( 'Icons', 'wildbook' ),
              'section' => 'sidebar_colors',
              'settings' => 'side_icons_color',
          )
      )
  ); 

  $wp_customize->add_setting( 'side_icons_hover_color',
    array(
      'default' => '#dbca9e',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'side_icons_hover_color',
          array(
              'label' => esc_html__( 'Icons (hover)', 'wildbook' ),
              'section' => 'sidebar_colors',
              'settings' => 'side_icons_hover_color',
          )
      )
  ); 

  $wp_customize->add_setting( 'side_social_icons_color',
    array(
      'default' => '#ffffff',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'side_social_icons_color',
          array(
              'label' => esc_html__( 'Social Icons', 'wildbook' ),
              'section' => 'sidebar_colors',
              'settings' => 'side_social_icons_color',
          )
      )
  ); 

  // Navigation Menu Colors

  $wp_customize->add_section( 'navigation_colors',
    array(
      'title' => esc_html__( 'Top primary menu', 'wildbook' ),
      'priority' => 10,
      'panel' => 'colors'
    )
  );

  $wp_customize->add_setting( 'right_nav_background_color',
    array(
      'default' => '#ffffff',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'right_nav_background_color',
          array(
              'label' => esc_html__( 'Background', 'wildbook' ),
              'section' => 'navigation_colors',
              'settings' => 'right_nav_background_color',
          )
      )
  );

  $wp_customize->add_setting( 'right_nav_links_color',
    array(
      'default' => '#333333',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'right_nav_links_color',
          array(
              'label' => esc_html__( 'Links', 'wildbook' ),
              'section' => 'navigation_colors',
              'settings' => 'right_nav_links_color',
          )
      )
  );

  $wp_customize->add_setting( 'right_nav_links_hover_color',
    array(
      'default' => '#a9874a',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'right_nav_links_hover_color',
          array(
              'label' => esc_html__( 'Links (hover)', 'wildbook' ),
              'section' => 'navigation_colors',
              'settings' => 'right_nav_links_hover_color',
          )
      )
  );

  $wp_customize->add_setting( 'right_nav_dropdown_background_color',
    array(
      'default' => '#f6f6f6',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'right_nav_dropdown_background_color',
          array(
              'label' => esc_html__( 'Drop-down menu', 'wildbook' ),
              'section' => 'navigation_colors',
              'settings' => 'right_nav_dropdown_background_color',
          )
      )
  );

  $wp_customize->add_setting( 'right_nav_dropdown_links_color',
    array(
      'default' => '#333333',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'right_nav_dropdown_links_color',
          array(
              'label' => esc_html__( 'Drop-down menu links', 'wildbook' ),
              'section' => 'navigation_colors',
              'settings' => 'right_nav_dropdown_links_color',
          )
      )
  );

  $wp_customize->add_setting( 'right_nav_dropdown_links_hover_color',
    array(
      'default' => '#a9874a',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'right_nav_dropdown_links_hover_color',
          array(
              'label' => esc_html__( 'Drop-down menu links (hover)', 'wildbook' ),
              'section' => 'navigation_colors',
              'settings' => 'right_nav_dropdown_links_hover_color',
          )
      )
  );
  
  $wp_customize->add_setting( 'right_nav_dot_color',
    array(
      'default' => '#e5d1ad',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'right_nav_dot_color',
          array(
              'label' => esc_html__( 'Dividers', 'wildbook' ),
              'section' => 'navigation_colors',
              'settings' => 'right_nav_dot_color',
          )
      )
  );

  $wp_customize->add_setting( 'right_nav_border_color',
    array(
      'default' => '#f2f2f2',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'right_nav_border_color',
          array(
              'label' => esc_html__( 'Border', 'wildbook' ),
              'section' => 'navigation_colors',
              'settings' => 'right_nav_border_color',
          )
      )
  );

  $wp_customize->add_setting( 'content_area_background_color',
    array(
      'default' => '#ffffff',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'content_area_background_color',
          array(
              'label' => esc_html__( 'Background', 'wildbook' ),
              'section' => 'colors',
              'settings' => 'content_area_background_color',
          )
      )
  );  

  $wp_customize->add_setting( 'content_area_text_color',
    array(
      'default' => '#4a4a4a',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'content_area_text_color',
          array(
              'label' => esc_html__( 'Text', 'wildbook' ),
              'section' => 'colors',
              'settings' => 'content_area_text_color',
          )
      )
  ); 

  $wp_customize->add_setting( 'content_area_secondary_text_color',
    array(
      'default' => '#bababa',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'content_area_secondary_text_color',
          array(
              'label' => esc_html__( 'Secondary Text', 'wildbook' ),
              'section' => 'colors',
              'settings' => 'content_area_secondary_text_color',
          )
      )
  );  

  $wp_customize->add_setting( 'content_area_headings_color',
    array(
      'default' => '#333333',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'content_area_headings_color',
          array(
              'label' => esc_html__( 'Headings', 'wildbook' ),
              'section' => 'colors',
              'settings' => 'content_area_headings_color',
          )
      )
  );  
   
  $wp_customize->add_setting( 'link_color',
    array(
      'default' => '#c8ab77',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'link_color',
          array(
              'label' => esc_html__( 'Links', 'wildbook' ),
              'section' => 'colors',
              'settings' => 'link_color',
          )
      )
  ); 
  
  $wp_customize->add_setting( 'link_color_hover',
    array(
      'default' => '#a9874a',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'link_color_hover',
          array(
              'label' => esc_html__( 'Links (hover)', 'wildbook' ),
              'section' => 'colors',
              'settings' => 'link_color_hover',
          )
      )
  ); 
  
  $wp_customize->add_setting( 'button_background_color',
    array(
      'default' => '#cbb78f',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'button_background_color',
          array(
              'label' => esc_html__( 'Buttons', 'wildbook' ),
              'section' => 'colors',
              'settings' => 'button_background_color',
          )
      )
  ); 
  
  $wp_customize->add_setting( 'button_background_color_on_hover',
    array(
      'default' => '#bba579',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'button_background_color_on_hover',
          array(
              'label' => esc_html__( 'Buttons (hover)', 'wildbook' ),
              'section' => 'colors',
              'settings' => 'button_background_color_on_hover',
          )
      )
  ); 
  
  $wp_customize->add_setting( 'button_text_color',
    array(
      'default' => '#ffffff',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'button_text_color',
          array(
              'label' => esc_html__( 'Buttons Text', 'wildbook' ),
              'section' => 'colors',
              'settings' => 'button_text_color',
          )
      )
  ); 
  
  $wp_customize->add_setting( 'share_button_background',
    array(
      'default' => '#f5f5f5',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'share_button_background',
          array(
              'label' => esc_html__( 'Share Buttons', 'wildbook' ),
              'section' => 'colors',
              'settings' => 'share_button_background',
          )
      )
  );
  
  $wp_customize->add_setting( 'share_button_icon_color',
    array(
      'default' => '#333333',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'share_button_icon_color',
          array(
              'label' => esc_html__( 'Share Buttons (icon)', 'wildbook' ),
              'section' => 'colors',
              'settings' => 'share_button_icon_color',
          )
      )
  );

  $wp_customize->add_setting( 'dividers_color',
    array(
      'default' => '#f2f2f2',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'dividers_color',
          array(
              'label' => esc_html__( 'Dividers', 'wildbook' ),
              'section' => 'colors',
              'settings' => 'dividers_color',
          )
      )
  ); 

  $wp_customize->add_section( 'other_colors',
    array(
      'title' => esc_html__( 'Other Colors', 'wildbook' ),
      'priority' => 20,
      'panel' => 'colors'
    )
  );

  $wp_customize->add_setting( 'preloader_color',
    array(
      'default' => '#c8ab77',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control(
      new WP_Customize_Color_Control(
          $wp_customize,
          'preloader_color',
          array(
              'label' => esc_html__( 'Preloader', 'wildbook' ),
              'section' => 'other_colors',
              'settings' => 'preloader_color',
          )
      )
  );

  /*
   * Titles & headings
   */
  $wp_customize->add_section( 'layout',
    array(
      'title' => esc_html__( 'Layout', 'wildbook' ),
      'priority' => 10
    )
  );


  $wp_customize->add_setting(
    'sidear_layout',
    array(
      'default' => 'layout-1',
      'sanitize_callback' => 'wdb_sidebar_layout_sanitize',
    )
  );
  
  $wp_customize->add_control(
      'sidear_layout',
      array(
        'type'    => 'select',
        'label'   => esc_html__( 'Sidebar Layout', 'wildbook' ),
        'section' => 'layout',
        'choices' => array(
          'layout-1' => esc_html__( 'Title at the middle', 'wildbook' ),
          'layout-2' => esc_html__( 'Title at the middle, social buttons at the bottom', 'wildbook' ),
          'layout-3' => esc_html__( 'Title at the bottom', 'wildbook' ),
          'layout-4' => esc_html__( 'Title at the top, navigation opened', 'wildbook' )
        )
      )
  );

  $wp_customize->add_setting(
    'sidebar_position',
    array(
      'default' => 'left',
      'sanitize_callback' => 'wdb_sidebar_position_sanitize',
    )
  );
  
  $wp_customize->add_control(
      'sidebar_position',
      array(
        'type'    => 'select',
        'label'   => esc_html__( 'Sidebar Position', 'wildbook' ),
        'section' => 'layout',
        'choices' => array(
          'left'  => is_rtl() ? esc_html__( 'Right', 'wildbook' ) : esc_html__( 'Left', 'wildbook' ),
          'right' =>  is_rtl() ? esc_html__( 'Left', 'wildbook' ) : esc_html__( 'Right', 'wildbook' )
        )
      )
  );

  $wp_customize->add_setting(
    'sidebar_width',
    array(
      'default' => '40',
      'sanitize_callback' => 'wdb_sidebar_width_sanitize',
    )
  );
  
  $wp_customize->add_control(
      'sidebar_width',
      array(
        'type'    => 'select',
        'label'   => esc_html__( 'Sidebar Width (%)', 'wildbook' ),
        'section' => 'layout',
        'choices' => array(
          '25' => 25,
          '30' => 30,
          '35' => 35,
          '40' => 40,
          '45' => 45,
          '50' => 50
        )
      )
  );

  $wp_customize->add_setting(
    'blog_layout',
    array(
      'default' => 'list',
      'sanitize_callback' => 'wdb_blog_layout_sanitize',
    )
  );
  
  $wp_customize->add_control(
      'blog_layout',
      array(
        'type'    => 'select',
        'label'   => esc_html__( 'Blog Layout', 'wildbook' ),
        'section' => 'layout',
        'choices' => array(
          'list'        => esc_html__( 'Standard', 'wildbook' ),
          'grid'        => esc_html__( 'Grid', 'wildbook' ),
          'simple-list' => esc_html__( 'List', 'wildbook' ),
        )
      )
  );

  /*
   * Additional Content Areas
   */

  $wp_customize->add_panel( 'custom_content_areas', array(
    'title'    => esc_html__( 'Additional Content Areas', 'wildbook' ),
  ) ); 

  $wp_customize->add_section( 'custom_content_areas_sidebar',
    array(
      'panel' => 'custom_content_areas',
      'title' => esc_html__( 'Sidebar', 'wildbook' )
    )
  ); 

  $wp_customize->add_setting( 'before_site_identity_content_page_id', array(
    'sanitize_callback' => 'absint',
    'default' => 0
  ) );

  $wp_customize->add_control( 'before_site_identity_content_page_id', array(
    'type'     => 'dropdown-pages',
    'priority' => 0,
    'section'  => 'custom_content_areas_sidebar',
    'label'    => __( 'Before Site Identity', 'wildbook' ),
    'description' => __( 'Select a page with content to appear before the site logo and tagline.', 'wildbook' )
  ) );

  $wp_customize->add_setting( 'after_site_identity_content_page_id', array(
    'sanitize_callback' => 'absint',
    'default' => 0
  ) );

  $wp_customize->add_control( 'after_site_identity_content_page_id', array(
    'type'     => 'dropdown-pages',
    'priority' => 0,
    'section'  => 'custom_content_areas_sidebar',
    'label'    => __( 'After Site Identity', 'wildbook' ),
    'description' => __( 'Select a page with content to appear after the site logo and tagline.', 'wildbook' )
  ) );

  $wp_customize->add_setting( 'before_site_copyright_content_page_id', array(
    'sanitize_callback' => 'absint',
    'default' => 0
  ) );

  $wp_customize->add_control( 'before_site_copyright_content_page_id', array(
    'type'     => 'dropdown-pages',
    'priority' => 0,
    'section'  => 'custom_content_areas_sidebar',
    'label'    => __( 'Before Site Copyright', 'wildbook' ),
    'description' => __( 'Select a page with content to appear before the site copyright.', 'wildbook' )
  ) );

  $wp_customize->add_setting( 'after_site_copyright_content_page_id', array(
    'sanitize_callback' => 'absint',
    'default' => 0
  ) );

  $wp_customize->add_control( 'after_site_copyright_content_page_id', array(
    'type'     => 'dropdown-pages',
    'priority' => 0,
    'section'  => 'custom_content_areas_sidebar',
    'label'    => __( 'After Site Copyright', 'wildbook' ),
    'description' => __( 'Select a page with content to appear after the site copyright.', 'wildbook' )
  ) );


  $wp_customize->add_section( 'custom_content_sections',
    array(
      'panel' => 'custom_content_areas',
      'title' => esc_html__( 'Content Area', 'wildbook' )
    )
  ); 

  $wp_customize->add_setting( 'after_top_nav_content_page_id', array(
    'sanitize_callback' => 'absint',
    'default' => 0
  ) );

  $wp_customize->add_control( 'after_top_nav_content_page_id', array(
    'type'     => 'dropdown-pages',
    'priority' => 0,
    'section'  => 'custom_content_sections',
    'label'    => __( 'After Top Navigation', 'wildbook' ),
    'description' => __( 'Select a page with content to appear after top navigation. This content will be displayed on all pages of the site.', 'wildbook' )
  ) );

  $wp_customize->add_setting( 'before_blog_posts_content_page_id', array(
    'sanitize_callback' => 'absint',
    'default' => 0
  ) );

  $wp_customize->add_control( 'before_blog_posts_content_page_id', array(
    'type'     => 'dropdown-pages',
    'priority' => 5,
    'section'  => 'custom_content_sections',
    'label'    => __( 'Before Blog Posts', 'wildbook' ),
    'description' => __( 'Select a page with content to appear before the list of blog posts.', 'wildbook' )
  ) );

  $wp_customize->add_setting( 'after_blog_posts_content_page_id', array(
    'sanitize_callback' => 'absint',
    'default' => 0
  ) );

  $wp_customize->add_control( 'after_blog_posts_content_page_id', array(
    'type'     => 'dropdown-pages',
    'priority' => 10,
    'section'  => 'custom_content_sections',
    'label'    => __( 'After Blog Posts', 'wildbook' ),
    'description' => __( 'Select a page with content to appear after the list of blog posts.', 'wildbook' )
  ) );

  $wp_customize->add_setting( 'before_single_post_content_page_id', array(
    'sanitize_callback' => 'absint',
    'default' => 0
  ) );

  $wp_customize->add_control( 'before_single_post_content_page_id', array(
    'type'     => 'dropdown-pages',
    'priority' => 15,
    'section'  => 'custom_content_sections',
    'label'    => __( 'Before Single Post', 'wildbook' ),
    'description' => __( 'Select a page with content to appear before single post content.', 'wildbook' )
  ) );

  $wp_customize->add_setting( 'after_single_post_content_page_id', array(
    'sanitize_callback' => 'absint',
    'default' => 0
  ) );

  $wp_customize->add_control( 'after_single_post_content_page_id', array(
    'type'     => 'dropdown-pages',
    'priority' => 20,
    'section'  => 'custom_content_sections',
    'label'    => __( 'After Single Post', 'wildbook' ),
    'description' => __( 'Select a page with content to appear after single post content.', 'wildbook' )
  ) );

  $wp_customize->add_setting( 'before_footer_content_page_id', array(
    'sanitize_callback' => 'absint',
    'default' => 0
  ) );

  $wp_customize->add_control( 'before_footer_content_page_id', array(
    'type'     => 'dropdown-pages',
    'priority' => 25,
    'section'  => 'custom_content_sections',
    'label'    => __( 'Before Footer', 'wildbook' ),
    'description' => __( 'Select a page with content to appear before footer of the site. This content will be displayed on all pages of the site.', 'wildbook' )
  ) );

  $wp_customize->add_setting( 'after_footer_content_page_id', array(
    'sanitize_callback' => 'absint',
    'default' => 0
  ) );

  $wp_customize->add_control( 'after_footer_content_page_id', array(
    'type'     => 'dropdown-pages',
    'priority' => 30,
    'section'  => 'custom_content_sections',
    'label'    => __( 'After Footer', 'wildbook' ),
    'description' => __( 'Select a page with content to appear after footer of the site. This content will be displayed on all pages of the site.', 'wildbook' )
  ) );
    
  /*
   * Titles & headings
   */
  $wp_customize->add_section( 'titles_and_headings',
    array(
      'title' => esc_html__( 'Titles', 'wildbook' )
    )
  );
  
  $wp_customize->add_setting( 'sticky_post_title',
    array(
      'default' => esc_html__( 'Featured', 'wildbook' ),
      'sanitize_callback' => 'sanitize_text_field',
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control( 'sticky_post_title', array(
    'type'        => 'text',
    'priority'    => 0,
    'label'       => esc_html__( 'Sticky post', 'wildbook' ),
    'section'     => 'titles_and_headings'
   ) );
   
  $wp_customize->add_setting( 'more_link_title',
    array(
      'sanitize_callback' => 'sanitize_text_field',
      'default' => esc_html__( 'Continue reading &rarr;', 'wildbook' ),
      'transport' => 'postMessage'
    )
  );

  $wp_customize->add_control( 'more_link_title', array(
    'type'        => 'text',
    'priority'    => 0,
    'label'       => esc_html__( 'Continue reading', 'wildbook' ),
    'section'     => 'titles_and_headings'
   ) );
   
  $wp_customize->add_setting( 'related_posts_title',
    array(
      'default' => esc_html__( 'You might also like', 'wildbook' ),
      'sanitize_callback' => 'sanitize_text_field',
      'transport' => 'postMessage'
    )
  );
  
  $wp_customize->add_control( 'related_posts_title', array(
    'type'        => 'text',
    'priority'    => 0,
    'label'       => esc_html__( 'Related Posts', 'wildbook' ),
    'section'     => 'titles_and_headings'
   ) );

  /*
   * Social Profiles
   */
  $wp_customize->add_section( 'social',
    array(
      'title' => esc_html__( 'Social Profiles', 'wildbook' )
    )
  );
  
  $wp_customize->add_setting( 'target_blank',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize'
    )
  );
  
  $wp_customize->add_control( 'target_blank', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Open link in a new window/tab', 'wildbook' ),
    'section'  => 'social',
  ) );
 
  $wp_customize->add_setting( 'social[facebook]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[facebook]', array(
    'type'     => 'url',
    'priority' => 10,
    'section'  => 'social',
    'label'    => esc_html__( 'Facebook', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[twitter]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[twitter]', array(
    'type'     => 'url',
    'priority' => 15,
    'section'  => 'social',
    'label'    => esc_html__( 'Twitter', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[googleplus]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[googleplus]', array(
    'type'     => 'url',
    'priority' => 20,
    'section'  => 'social',
    'label'    => esc_html__( 'Google Plus', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[bloglovin]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[bloglovin]', array(
    'type'     => 'url',
    'priority' => 20,
    'section'  => 'social',
    'label'    => esc_html__( 'Bloglovin', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[instagram]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[instagram]', array(
    'type'     => 'url',
    'priority' => 25,
    'section'  => 'social',
    'label'    => esc_html__( 'Instagram', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[pinterest]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[pinterest]', array(
    'type'     => 'url',
    'priority' => 30,
    'section'  => 'social',
    'label'    => esc_html__( 'Pinterest', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[linkedin]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[linkedin]', array(
    'type'     => 'url',
    'priority' => 35,
    'section'  => 'social',
    'label'    => esc_html__( 'LinkedIn', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[flickr]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[flickr]', array(
    'type'     => 'url',
    'priority' => 40,
    'section'  => 'social',
    'label'    => esc_html__( 'Flickr', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[medium]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[medium]', array(
    'type'     => 'url',
    'priority' => 45,
    'section'  => 'social',
    'label'    => esc_html__( 'Medium', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[vkontakte]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[vkontakte]', array(
    'type'     => 'url',
    'priority' => 50,
    'section'  => 'social',
    'label'    => esc_html__( 'Vkontakte', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[f500px]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[f500px]', array(
    'type'     => 'url',
    'priority' => 55,
    'section'  => 'social',
    'label'    => esc_html__( '500px', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[tumblr]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[tumblr]', array(
    'type'     => 'url',
    'priority' => 60,
    'section'  => 'social',
    'label'    => esc_html__( 'Tumblr', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[dribbble]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[dribbble]', array(
    'type'     => 'url',
    'priority' => 65,
    'section'  => 'social',
    'label'    => esc_html__( 'Dribbble', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[behance]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[behance]', array(
    'type'     => 'url',
    'priority' => 70,
    'section'  => 'social',
    'label'    => esc_html__( 'Behance', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[youtube]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[youtube]', array(
    'type'     => 'url',
    'priority' => 75,
    'section'  => 'social',
    'label'    => esc_html__( 'YouTube', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[vimeo]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[vimeo]', array(
    'type'     => 'url',
    'priority' => 80,
    'section'  => 'social',
    'label'    => esc_html__( 'Vimeo', 'wildbook' ),
  ) );

  $wp_customize->add_setting( 'social[github]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[github]', array(
    'type'     => 'url',
    'priority' => 81,
    'section'  => 'social',
    'label'    => esc_html__( 'Github', 'wildbook' ),
  ) );

  $wp_customize->add_setting( 'social[xing]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[xing]', array(
    'type'     => 'url',
    'priority' => 85,
    'section'  => 'social',
    'label'    => esc_html__( 'Xing', 'wildbook' ),
  ) );

  $wp_customize->add_setting( 'social[soundcloud]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[soundcloud]', array(
    'type'     => 'url',
    'priority' => 90,
    'section'  => 'social',
    'label'    => esc_html__( 'SoundCloud', 'wildbook' ),
  ) );

  $wp_customize->add_setting( 'social[yelp]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[yelp]', array(
    'type'     => 'url',
    'priority' => 95,
    'section'  => 'social',
    'label'    => esc_html__( 'Yelp', 'wildbook' ),
  ) ); 

  $wp_customize->add_setting( 'social[etsy]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[etsy]', array(
    'type'     => 'url',
    'priority' => 100,
    'section'  => 'social',
    'label'    => esc_html__( 'Etsy', 'wildbook' ),
  ) ); 

  $wp_customize->add_setting( 'social[odnoklassniki]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[odnoklassniki]', array(
    'type'     => 'url',
    'priority' => 105,
    'section'  => 'social',
    'label'    => esc_html__( 'Odnoklassniki', 'wildbook' ),
  ) ); 

  $wp_customize->add_setting( 'social[snapchat]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[snapchat]', array(
    'type'     => 'url',
    'priority' => 110,
    'section'  => 'social',
    'label'    => esc_html__( 'Snapchat', 'wildbook' ),
  ) ); 

  $wp_customize->add_setting( 'social[steam]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[steam]', array(
    'type'     => 'url',
    'priority' => 115,
    'section'  => 'social',
    'label'    => esc_html__( 'Steam', 'wildbook' ),
  ) ); 

  $wp_customize->add_setting( 'social[reddit]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[reddit]', array(
    'type'     => 'url',
    'priority' => 116,
    'section'  => 'social',
    'label'    => esc_html__( 'Reddit', 'wildbook' ),
  ) ); 
  
  $wp_customize->add_setting( 'social[rss]',
    array(
      'default' => '',
      'sanitize_callback' => 'esc_url_raw'
    )
  );
  
  $wp_customize->add_control( 'social[rss]', array(
    'type'     => 'url',
    'priority' => 120,
    'section'  => 'social',
    'label'    => esc_html__( 'Rss', 'wildbook' ),
  ) );
  
  $wp_customize->add_setting( 'social[email]',
    array(
      'default' => '',
      'sanitize_callback' => 'wdb_email_sanitize'
    )
  );
  
  $wp_customize->add_control( 'social[email]', array(
    'type'     => 'url',
    'priority' => 125,
    'section'  => 'social',
    'label'    => esc_html__( 'Email', 'wildbook' ),
  ) );

  
  
  /*
   * Post Options
   */
  $wp_customize->add_section( 'post_options',
    array(
      'title' => esc_html__( 'Post Options', 'wildbook' )
    )
  ); 
  
  $wp_customize->add_setting( 'thumbnail_hard_crop',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'thumbnail_hard_crop', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Crop Featured image', 'wildbook' ),
    'section'  => 'post_options',
  ) );
  
  $wp_customize->add_setting( 'display_categories',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_categories', array(
    'type'     => 'checkbox',
    'priority' => 5,
    'label'    => esc_html__( 'Display categories', 'wildbook' ),
    'section'  => 'post_options',
  ) );
  
  $wp_customize->add_setting( 'display_date',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_date', array(
    'type'     => 'checkbox',
    'priority' => 10,
    'label'    => esc_html__( 'Display post date', 'wildbook' ),
    'section'  => 'post_options',
  ) );
  
  $wp_customize->add_setting( 'display_author_name',
    array(
      'default' => 0,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_author_name', array(
    'type'     => 'checkbox',
    'priority' => 15,
    'label'    => esc_html__( 'Display author name', 'wildbook' ),
    'section'  => 'post_options',
  ) );
  
  $wp_customize->add_setting( 'display_comments_number',
    array(
      'default' => 0,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_comments_number', array(
    'type'     => 'checkbox',
    'priority' => 11,
    'label'    => esc_html__( 'Display comment count', 'wildbook' ),
    'section'  => 'post_options',
  ) );

  $wp_customize->add_setting( 'display_tags_list',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_tags_list', array(
    'type'     => 'checkbox',
    'priority' => 20,
    'label'    => esc_html__( 'Display tags', 'wildbook' ),
    'section'  => 'post_options',
  ) );
  
  $wp_customize->add_setting( 'display_share_buttons',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_share_buttons', array(
    'type'     => 'checkbox',
    'priority' => 25,
    'label'    => esc_html__( 'Display share buttons', 'wildbook' ),
    'section'  => 'post_options',
  ) );
  
  $wp_customize->add_setting( 'display_published_by',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_published_by', array(
    'type'     => 'checkbox',
    'priority' => 30,
    'label'    => esc_html__( 'Display author info', 'wildbook' ),
    'section'  => 'post_options',
  ) );

  $wp_customize->add_setting( 'display_post_navigation',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_post_navigation', array(
    'type'     => 'checkbox',
    'priority' => 35,
    'label'    => esc_html__( 'Display previous/next post navigation', 'wildbook' ),
    'section'  => 'post_options',
  ) );
  
  $wp_customize->add_setting( 'display_related_posts',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_related_posts', array(
    'type'     => 'checkbox',
    'priority' => 35,
    'label'    => esc_html__( 'Display related posts', 'wildbook' ),
    'section'  => 'post_options',
  ) );
  
  $wp_customize->add_setting(
    'related_by',
    array(
      'default' => 'none',
      'sanitize_callback' => 'wdb_related_by_sanitize',
    )
  );
  
  $wp_customize->add_control(
      'related_by',
      array(
        'type'    => 'select',
        'priority' => 40,
        'label'   => esc_html__( 'Related posts by', 'wildbook' ),
        'section' => 'post_options',
        'choices' => array(
          'category' => esc_html__( 'category', 'wildbook' ),
          'tags'     => esc_html__( 'tags', 'wildbook' ),
          'none'     => esc_html__( 'unknown criteria (random posts)', 'wildbook' )
        )
      )
  );
  
  /*
   * Page Options
   */
  $wp_customize->add_section( 'page_options',
    array(
      'title' => esc_html__( 'Page Options', 'wildbook' )
    )
  ); 
  
  $wp_customize->add_setting( 'display_page_share_buttons',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_page_share_buttons', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Display share buttons', 'wildbook' ),
    'section'  => 'page_options',
  ) );
  
  /*
   * Share buttons
   */
  $wp_customize->add_section( 'share_buttons',
    array(
      'title' => esc_html__( 'Share Buttons', 'wildbook' )
    )
  ); 
  
  $wp_customize->add_setting( 'display_facebook_share_button',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_facebook_share_button', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Facebook', 'wildbook' ),
    'section'  => 'share_buttons',
  ) );
  
  $wp_customize->add_setting( 'display_twitter_share_button',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_twitter_share_button', array(
    'type'     => 'checkbox',
    'priority' => 5,
    'label'    => esc_html__( 'Twitter', 'wildbook' ),
    'section'  => 'share_buttons',
  ) );
  
  $wp_customize->add_setting( 'display_google_share_button',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_google_share_button', array(
    'type'     => 'checkbox',
    'priority' => 10,
    'label'    => esc_html__( 'Google Plus', 'wildbook' ),
    'section'  => 'share_buttons',
  ) );
  
  $wp_customize->add_setting( 'display_pinterest_share_button',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_pinterest_share_button', array(
    'type'     => 'checkbox',
    'priority' => 15,
    'label'    => esc_html__( 'Pinterest', 'wildbook' ),
    'section'  => 'share_buttons',
  ) );
  
  $wp_customize->add_setting( 'display_tumblr_share_button',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_tumblr_share_button', array(
    'type'     => 'checkbox',
    'priority' => 15,
    'label'    => esc_html__( 'Tumblr', 'wildbook' ),
    'section'  => 'share_buttons',
  ) );

  $wp_customize->add_setting( 'display_vk_share_button',
    array(
      'default' => 0,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_vk_share_button', array(
    'type'     => 'checkbox',
    'priority' => 15,
    'label'    => esc_html__( 'Vkontakte', 'wildbook' ),
    'section'  => 'share_buttons',
  ) );
  
  /*
   * Footer
   */  
  $wp_customize->add_section( 'footer',
    array(
      'title' => esc_html__( 'Copyright', 'wildbook' )
    )
  ); 

  $wp_customize->add_setting(
    'copyright',
    array(
      'default' => '',
      'sanitize_callback' => 'wdb_textarea_sanitize',
      'transport' => 'postMessage'
    )
  );
 
  $wp_customize->add_control(
      'copyright',
      array(
        'type'    => 'textarea',
        'label'   => esc_html__( 'Copyright Text', 'wildbook' ),
        'description' => esc_html__( 'You may use these HTML tags and attributes: a[href,title], strong, b, em, i, img[src,alt,title], p, span, br', 'wildbook' ),
        'section' => 'footer',
      )
  );

  $wp_customize->add_setting( 'display_copyright',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'display_copyright', array(
    'type'     => 'checkbox',
    'priority' => 10,
    'label'    => esc_html__( 'Display copyright', 'wildbook' ),
    'section'  => 'footer',
  ) );
  
  /*
   * Custom CSS
   */
  $wp_customize->add_setting(
		'wdb_custom_css',
		array(
			'default'           => '',
			'sanitize_callback' => 'wp_filter_nohtml_kses'
		)
	);
	
	$wp_customize->add_control(
		'wdb_custom_css',
		array(
			'section'  => 'custom_css',
			'settings' => 'wdb_custom_css',
			'type'     => 'textarea'
		)
	);
	
  /*
   * Other options
   */  
  $wp_customize->add_section( 'other_options',
    array(
      'title' => esc_html__( 'Other Options', 'wildbook' )
    )
  ); 
  
  $wp_customize->add_setting( 'show_preloader_screen',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'show_preloader_screen', array(
    'type'     => 'checkbox',
    'priority' => 0,
    'label'    => esc_html__( 'Display loading screen', 'wildbook' ),
    'section'  => 'other_options',
  ) );
  
 $wp_customize->add_setting( 'sticky_menu',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'sticky_menu', array(
    'type'     => 'checkbox',
    'priority' => 20,
    'label'    => esc_html__( 'Enable sticky menu', 'wildbook' ),
    'section'  => 'other_options'
  ) );

  $wp_customize->add_setting( 'show_search',
    array(
      'default' => 1,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'show_search', array(
    'type'     => 'checkbox',
    'priority' => 10,
    'label'    => esc_html__( 'Display search', 'wildbook' ),
    'section'  => 'other_options',
  ) );
  
  $wp_customize->add_setting( 'winter_mode',
    array(
      'default' => 0,
      'sanitize_callback' => 'wdb_checkbox_sanitize',
    )
  );
  
  $wp_customize->add_control( 'winter_mode', array(
    'type'     => 'checkbox',
    'priority' => 30,
    'label'    => esc_html__( 'Enable falling snow', 'wildbook' ),
    'section'  => 'other_options'
  ) );

}
add_action( 'customize_register', 'wdb_customize_register' );

/**
 * Binds JS handlers to make the Customizer preview reload changes asynchronously.
 *
 * @since Wild Book 1.4.3
 */
function wildbook_customize_preview_js() {
	wp_enqueue_script( 'wildbook-customize-preview', get_template_directory_uri() . '/js/admin/customize-preview.js', array( 'customize-preview' ), '20172707', true );

  wp_localize_script( 
    'wildbook-customize-preview', 
    'wildbookCustomizerDefaults', 
    array( 
      'relatedPostsTitle'   => esc_html__( 'You might also like', 'wildbook' ),
      'stickyPostBadgeText' => esc_html__( 'Featured', 'wildbook' ),
      'moreLinkText'        => esc_html__( 'Continue reading &rarr;', 'wildbook' ),
      'copyright'           => sprintf( '&copy; %1$d <a href="%2$s">%3$s</a>', date('Y'), esc_url( home_url( '/' ) ), esc_html( get_bloginfo( 'name' ) ) )
    )
  ); 
}
add_action( 'customize_preview_init', 'wildbook_customize_preview_js' );

if ( ! function_exists( 'wdb_background_size_sanitize' ) ) :
  /**
   * Sanitization callback for background size option.
   *
   * @since Wild Book 1.0
   */
  function wdb_background_size_sanitize( $value ) {
    $background_sizes = array( 'auto', 'cover', 'contain' );
    if ( ! in_array( $value, $background_sizes ) ) {
      $value = 'auto';
    }

    return $value;
  }
endif;

if ( ! function_exists( 'wdb_background_position_y_sanitize' ) ) :
  /**
   * Sanitization callback for background y-position option.
   *
   * @since Wild Book 1.5
   */
  function wdb_background_position_y_sanitize( $value ) {
    $background_positions = array( 'top', 'center', 'bottom' );
    if ( ! in_array( $value, $background_positions ) ) {
      $value = 'center';
    }

    return $value;
  }
endif;

if ( ! function_exists( 'wdb_email_sanitize' ) ) :
  /**
   * Sanitization callback for email field.
   *
   * @since Wild Book 1.0
   * @return string|null Verified email adress or null.
   */
  function wdb_email_sanitize( $value ) {
    return ( is_email( $value ) ) ? $value : '';
  }
endif;

if ( ! function_exists( 'wdb_textarea_sanitize' ) ) :
  /**
   * Sanitization callback for textarea field.
   *
   * @since Wild Book 1.0
   * @return string Textarea value.
   */
  function wdb_textarea_sanitize( $value ) {
    if( $value ) {
      $value = wp_unslash( wp_kses( $value, array(
          'a' => array(
            'href' => array(),
            'title' => array(),
            'target' => array()
          ),
          'b'      => array(),
          'strong' => array(),
          'em'     => array(),
          'i'      => array(),
          'img' => array(
            'src' => array(),
            'alt' => array(),
            'title' => array()
          ),
          'span' => array(),
          'br' => array(),
          'p'  => array()
        ) )
      );
    }

    return $value;
  }
endif;

if ( ! function_exists( 'wdb_checkbox_sanitize' ) ) :
  /**
   * Sanitization callback for checkbox.
   *
   * @since Wild Book 1.0
   */
  function wdb_checkbox_sanitize( $value ) {
    if ( $value == 1 ) {
        return 1;
    } else {
        return '';
    }
  }
endif;

if ( ! function_exists( 'wdb_related_by_sanitize' ) ) :
  /**
   * Sanitization callback for "related by" select.
   *
   * @since Wild Book 1.0
   */
  function wdb_related_by_sanitize( $value ) {
    $related_bys = array( 'category', 'tags', 'none' );
    if ( ! in_array( $value, $related_bys ) ) {
      $value = 'category';
    }

    return $value;
  }
endif;

if ( ! function_exists( 'wdb_opacity_sanitize' ) ) :
  /**
   * Sanitization callback for opacity range slider.
   *
   * @since Wild Book 1.0
   */
  function wdb_opacity_sanitize( $value ) {
    if ( is_numeric( $value ) && $value >= 0 && $value <= 1 )
      return $value;

    return 0.75;
  }
endif;

if ( ! function_exists( 'wdb_logo_size_sanitize' ) ) :
  /**
   * Sanitization callback for width range slider.
   *
   * @since Wild Book 1.4.6
   */
  function wdb_logo_size_sanitize( $value ) {
    if ( is_numeric( $value ) && $value >= 1 && $value <= 30 )
      return $value;

    return 13;
  }
endif;

if ( ! function_exists( 'wdb_logo_margin_bottom_sanitize' ) ) :
  /**
   * Sanitization callback for margin range slider.
   *
   * @since Wild Book 1.4.6
   */
  function wdb_logo_margin_bottom_sanitize( $value ) {
    if ( is_numeric( $value ) && $value >= 1 && $value <= 6 )
      return $value;

    return 1.8;
  }
endif;

if ( ! function_exists( 'wdb_blog_layout_sanitize' ) ) :
  /**
   * Sanitization callback for "Blog layout" select.
   *
   * @since Wild Book 1.4.7
   */
  function wdb_blog_layout_sanitize( $value ) {
    $layouts = array( 'list', 'grid', 'simple-list' );
    if ( ! in_array( $value, $layouts ) ) {
      $value = 'list';
    }

    return $value;
  }
endif;

if ( ! function_exists( 'wdb_sidebar_position_sanitize' ) ) :
  /**
   * Sanitization callback for "Sidebar Position" select.
   *
   * @since Wild Book 1.4.9
   */
  function wdb_sidebar_position_sanitize( $value ) {
    $positions = array( 'left', 'right' );
    if ( ! in_array( $value, $positions ) ) {
      $value = 'left';
    }

    return $value;
  }
endif;

if ( ! function_exists( 'wdb_sidebar_width_sanitize' ) ) :
  /**
   * Sanitization callback for "Sidebar Width" select.
   *
   * @since Wild Book 1.4.9
   */
  function wdb_sidebar_width_sanitize( $value ) {
    $sizes = array( 25, 30, 35, 40, 45, 50 );
    if ( ! in_array( $value, $sizes ) ) {
      $value = 40;
    }

    return $value;
  }
endif;

if ( ! function_exists( 'wdb_sidebar_layout_sanitize' ) ) :
  /**
   * Sanitization callback for "Sidebar Layout" select.
   *
   * @since Wild Book 1.5
   */
  function wdb_sidebar_layout_sanitize( $value ) {
    $layouts = array( 'layout-1', 'layout-2', 'layout-3', 'layout-4', 'layout-5', 'layout-6' );
    if ( ! in_array( $value, $layouts ) ) {
      $value = 'layout-1';
    }

    return $value;
  }
endif;

?>