/**
 * Live-update changed settings in real time in the Customizer preview.
 */

( function( $ ) {
	var api = wp.customize,
		$head = $('head');

	function hexToRgba( hex, opacity ) {
		var red = parseInt( hex.substring(1, 3), 16 ),
			green = parseInt( hex.substring(3, 5), 16 ),
			blue = parseInt( hex.substring(5, 7), 16 );

		return 'rgba( ' + red + ', ' + green + ', ' + blue + ', ' + opacity + ' )';
	}

	// Blog Title
	api( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a' ).text( to );
		} );
	} );

	// Tagline
	api( 'tagline', function( value ) {
		value.bind( function( to ) {
			$( '.tagline' ).html( to );
		} );
	} );
	
	// Blackout
	api( 'background_dark_mask_opacity', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-dark-mask-opacity-css'),
				css = 'opacity: ' + parseFloat( to );

			style.remove();
			style = $('<style type="text/css" id="custom-dark-mask-opacity-css">.sidebar:before { ' + css + ' } </style>').appendTo( $head );
		} );
	} );
	
	// Logo size
	api( 'logo_size', function( value ) {
		value.bind( function( to ) {
      		$( '.header-image img' ).css( 'max-width', parseFloat( to ) + 'em' );
		} );
	} );
	
	api( 'logo_margin_bottom', function( value ) {
		value.bind( function( to ) {
			$( '.header-image' ).css( 'margin-bottom', parseFloat( to ) + 'em' );
		} );
	} );
	
	api( 'header_image_rounded', function( value ) {
		value.bind( function( to ) {
			if( to ) {
				$( '.header-image' ).addClass( 'rounded' );
			} else {
				$( '.header-image' ).removeClass( 'rounded' );
			}
		} );
	} );
	
	// Related posts title
	api( 'related_posts_title', function( value ) {
		value.bind( function( to ) {
      if( $.trim( to ).length ) {
        $( '.related-posts-title' ).text( to );
      } else {
        $( '.related-posts-title' ).text( wildbookCustomizerDefaults.relatedPostsTitle );
      }
		} );
	} );
	
  	// Sticky post title
	api( 'sticky_post_title', function( value ) {
		value.bind( function( to ) {
      if( $.trim( to ).length ) {
        $( '.sticky-badge' ).text( to );
      } else {
        $( '.sticky-badge' ).text( wildbookCustomizerDefaults.stickyPostBadgeText );
      }
		} );
	} );
	
	// More link text
	api( 'more_link_title', function( value ) {
		value.bind( function( to ) {
      if( $.trim( to ).length ) {
        $( '.more-link span' ).text( to );
      } else {
        $( '.more-link span' ).text( wildbookCustomizerDefaults.moreLinkText );
      }
		} );
	} );
	
	// Copyright
	api( 'copyright', function( value ) {
		value.bind( function( to ) {
      if( $.trim( to ).length ) {
        $( '.site-info' ).html( to );
      } else {
        $( '.site-info' ).html( wildbookCustomizerDefaults.copyright );
      }
		} );
	} );

	// Sidebar Colors
	api( 'side_text_color', function( value ) {
		value.bind( function( to ) {
			$( '.sidebar' ).css( 'color', to )
		} );
	} );

	api( 'main_nav_link_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-sidebar-links-color-css'),
				css = 'color: ' +  to;

			style.remove();
			style = $('<style type="text/css" id="custom-sidebar-links-color-css"> .sidebar a { ' + css + ' } </style>').appendTo( $head );
		} );
	} );

	api( 'main_nav_link_hover_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-sidebar-links-hover-color-css'),
				css = 'color: ' +  to;

			style.remove();
			style = $( '<style type="text/css" id="custom-sidebar-links-hover-color-css"> .sidebar a:hover { ' + css + ' } { background-color:' + to + ' }</style>' ).appendTo( $head );
		} );
	} );

	api( 'side_icons_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-sidebar-icons-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-sidebar-icons-color-css"> .nav-toggle .menu-icon, .nav-toggle .menu-icon:before, .nav-toggle .menu-icon:after { background-color:' + to + ' } .toggle-buttons .search-toggle { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	api( 'side_icons_hover_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-sidebar-icons-hover-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-sidebar-icons-hover-color-css"> .nav-toggle:hover .menu-icon, .nav-toggle:hover .menu-icon:before, .nav-toggle:hover .menu-icon:after { background-color:' + to + ' } .toggle-buttons .search-toggle:hover { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	api( 'side_social_icons_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-sidebar-social-icons-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-sidebar-social-icons-color-css"> .sidebar .social-profiles { color:' + to + ' } .sidebar .social-profiles a { border-color: ' + hexToRgba( to, 0.3 ) + ' } .sidebar .social-profiles a:hover { border-color: ' + hexToRgba( to, 0.5 ) + ' } </style>' ).appendTo( $head );
		} );
	} );

	// Navigation Menu Colors

	api( 'right_nav_background_color', function( value ) {
		value.bind( function( to ) {
			$( '#top-nav' ).css( 'background-color', to )
		} );
	} );

	api( 'right_nav_links_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-top-nav-links-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-top-nav-links-color-css"> @media (min-width: 992px) { .top-nav .nav-menu > li > a  { color:' + to + ' } } .top-nav-toggle { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	api( 'right_nav_links_hover_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-top-nav-links-hover-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-top-nav-links-hover-color-css"> @media (min-width: 992px) { .top-nav .nav-menu > li > a:hover  { color:' + to + ' } } .top-nav-toggle:hover { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	api( 'right_nav_dropdown_background_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-top-nav-dropdown-background-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-top-nav-dropdown-background-color-css"> @media (min-width: 992px) { .top-nav .nav-menu .sub-menu { background-color:' + to + ' } } </style>' ).appendTo( $head );
		} );
	} );

	api( 'right_nav_dropdown_links_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-top-nav-dropdown-links-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-top-nav-dropdown-links-color-css"> @media (min-width: 992px) { .top-nav .nav-menu .sub-menu > li > a { color:' + to + ' } } </style>' ).appendTo( $head );
		} );
	} );

	api( 'right_nav_dropdown_links_hover_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-top-nav-dropdown-links-hover-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-top-nav-dropdown-links-hover-color-css"> @media (min-width: 992px) { .top-nav .nav-menu .sub-menu > li > a:hover { color:' + to + ' } } </style>' ).appendTo( $head );
		} );
	} );

	api( 'right_nav_dot_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-top-nav-dividers-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-top-nav-dividers-color-css"> .top-nav .nav-menu > li > a:after { background-color:' + to + ' }</style>' ).appendTo( $head );
		} );
	} );

	api( 'right_nav_border_color', function( value ) {
		value.bind( function( to ) {
			$( '#top-nav' ).css( 'border-color', to );
			$( '#top-nav-toggle' ).css( 'border-color', to );
		} );
	} );

	// Content Area Colors
	api( 'content_area_background_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-content-area-background-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-content-area-background-color-css"> .site-content, blockquote:before, blockquote:after { background-color:' + to + ' }</style>' ).appendTo( $head );
		} );
	} );

	api( 'content_area_text_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-content-area-text-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-content-area-text-color-css"> body, a { color:' + to + ' } a:hover { color:' + hexToRgba( to, 0.5 ) + ' } table, th, td { border-color:' + hexToRgba( to, 0.15 ) + ' } hr, .text-box, pre { border-color:' + hexToRgba( to, 0.15 ) + ' } blockquote:before, blockquote:after { color:' + hexToRgba( to, 0.15 ) + ' } .cat-links:after { background-color:' + hexToRgba( to, 0.15 ) + ' } .comment-reply-link{ color:' + to + '; border-color:' + hexToRgba( to, 0.15 ) + ' } .comment-reply-link:hover{ color:' + hexToRgba( to, 0.75 ) + '; border-color:' + hexToRgba( to, 0.35 ) + ' } </style>' ).appendTo( $head );
		} );
	} );

	api( 'content_area_secondary_text_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-content-area-secondary-text-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-content-area-secondary-text-color-css"> .post-meta, .post-date, .comment-meta, .entry-meta .portfolio-cats a, .comment-list .bypostauthor .fn:after, .post-navigation .nav-meta, .widget_archive ul, .widget_categories ul, .widget_recent_comments ul, caption, .wp-caption-text, .entry-caption p, .tags-list a, .tagcloud a, .tags-list a:hover, .tagcloud a:hover { color:' + to + ' } .post-meta + .post-meta:before { color:' + hexToRgba( to, 0.75 ) + ' } .tags-list a, .tagcloud a { border-color:' + hexToRgba( to, 0.2 ) + ' } .tags-list a:hover, .tagcloud a:hover { border-color:' + hexToRgba( to, 0.5 ) + ' } </style>' ).appendTo( $head );
		} );
	} );


	api( 'content_area_headings_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-content-area-headings-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-content-area-headings-color-css"> h1, h2, h3, h4, h5, h6 { color:' + to + ' } .entry-title a:hover { color:' + hexToRgba( to, 0.75 ) + ' } </style>' ).appendTo( $head );
		} );
	} );

	api( 'link_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-link-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-link-color-css"> .taxonomy-description a, .entry-meta a, .page-content a, .entry-content a, .author-info a, .comment-navigation a, .image-navigation a, .comment-content a, .pingback .comment-body > a, .comment-meta a, .logged-in-as a, .widget_calendar a, .textwidget a { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );


	api( 'link_color_hover', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-link-hover-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-link-hover-color-css"> .taxonomy-description a:hover, .cat-links a:hover, .entry-meta a:hover, .page-content a:hover, .entry-content a:hover, .author-info a:hover, .comment-navigation a:hover, .image-navigation a:hover, .comment-content a:hover, .comment-meta a:hover, .logged-in-as a:hover, .widget_calendar a:hover, .textwidget a:hover, .portfolio-grid .portfolio-cats a:hover { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	api( 'button_background_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-button-background-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-button-background-color-css"> button, input[type="button"], input[type="reset"], input[type="submit"], .pagination .page-numbers:hover, .pagination .page-numbers.current { background-color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	api( 'button_background_color_on_hover', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-button-background-hover-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-button-background-hover-color-css"> button:hover, input[type="button"]:hover, input[type="reset"]:hover, input[type="submit"]:hover { background-color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	api( 'button_text_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-button-text-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-button-text-color-css"> button, input[type="button"], input[type="reset"], input[type="submit"], .pagination .page-numbers:hover, .pagination .page-numbers.current { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	api( 'share_button_background', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-share-buttons-background-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-share-buttons-background-color-css"> .share-buttons a { background-color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	api( 'share_button_icon_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-share-buttons-icon-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-share-buttons-icon-color-css"> .share-buttons a { color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

	api( 'dividers_color', function( value ) {
		value.bind( function( to ) {
			var style = $('#custom-dividers-color-css');

			style.remove();
			style = $( '<style type="text/css" id="custom-dividers-color-css"> .navigation, .inner-box, .content-area { border-color:' + to + ' } </style>' ).appendTo( $head );
		} );
	} );

} )( jQuery );
